@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Handler::DMARC;
 use strict;
 use warnings;
 use base 'Mail::Milter::Authentication::Handler';
-our $VERSION = '2.20191206'; # VERSION
+our $VERSION = '2.20200102'; # VERSION
 
 use Data::Dumper;
 use English qw{ -no_match_vars };
@@ -388,10 +388,11 @@ sub _process_dmarc_for {
     my $dmarc_result = $dmarc->validate();
     my $is_subdomain = $dmarc->is_subdomain();
 
-    # ToDo Set multiple dmarc_result objects here
-    # this will become relevant when the BIMI handler
-    # is production ready.
     $self->set_object('dmarc_result', $dmarc_result, 1 );
+    my $dmarc_results = $self->get_object('dmarc_results');
+    $dmarc_results = [] if ! $dmarc_results;
+    push @$dmarc_results, $dmarc_result;
+    $self->set_object('dmarc_results',$dmarc_results,1);
 
     my $dmarc_code   = $dmarc_result->result;
     $self->dbgout( 'DMARCCode', $dmarc_code, LOG_INFO );
@@ -907,6 +908,7 @@ sub close_callback {
     delete $self->{'report_queue'};
     $self->destroy_object('dmarc');
     $self->destroy_object('dmarc_result');
+    $self->destroy_object('dmarc_results');
     return;
 }
 
@@ -924,7 +926,7 @@ Mail::Milter::Authentication::Handler::DMARC
 
 =head1 VERSION
 
-version 2.20191206
+version 2.20200102
 
 =head1 DESCRIPTION
 
@@ -965,7 +967,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Marc Bradshaw.
+This software is copyright (c) 2020 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
