@@ -2,7 +2,7 @@ package Mail::Milter::Authentication::Tester::HandlerTester;
 
 use strict;
 use warnings;
-our $VERSION = '2.20191206'; # VERSION
+our $VERSION = '2.20200102'; # VERSION
 
 use Carp;
 use Clone qw{ clone };
@@ -204,12 +204,14 @@ sub connect { ## no critic
     my $ip_obj = eval{ Net::IP->new( $ip ) } // undef;
     # An undef here should not make it through to handlers, however
     # for testing we will allow this.
-    return $self->handler()->top_connect_callback( $name, $ip_obj );
+    $self->handler()->remap_connect_callback( $name, $ip_obj );
+    return $self->handler()->top_connect_callback( $name, $self->handler()->{ 'ip_object' } );
 }
 
 sub helo {
     my ( $self, $helo ) = @_;
-    return $self->handler()->top_helo_callback( $helo );
+    $self->handler()->remap_helo_callback( $helo );
+    return $self->handler()->top_helo_callback( $self->handler()->{ 'helo_name' } );
 }
 
 sub mailfrom {
@@ -367,7 +369,7 @@ Mail::Milter::Authentication::Tester::HandlerTester
 
 =head1 VERSION
 
-version 2.20191206
+version 2.20200102
 
 =head1 SYNOPSIS
 
@@ -587,7 +589,7 @@ Marc Bradshaw <marc@marcbradshaw.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Marc Bradshaw.
+This software is copyright (c) 2020 by Marc Bradshaw.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
